==> haskell-foldl-1.4.16-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 foldl
version:              1.4.16
visibility:           public
id:                   foldl-1.4.16-F6aCYvXCrBptEdT4ZqrtB
key:                  foldl-1.4.16-F6aCYvXCrBptEdT4ZqrtB
license:              BSD-3-Clause
copyright:            2013 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.

category:             Control
abi:                  c2a07001d1e35b0b8bff3b6c3830b96b
exposed:              True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.NonEmpty
    Control.Foldl.Text Control.Scanl

hidden-modules:
    Control.Foldl.Optics Control.Foldl.Internal
    Control.Foldl.Util.Vector Control.Foldl.Util.MVector

import-dirs:          /usr/lib/ghc-9.2.8/site-local/foldl-1.4.16
library-dirs:         /usr/lib/ghc-9.2.8/site-local/foldl-1.4.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foldl
hs-libraries:         HSfoldl-1.4.16-F6aCYvXCrBptEdT4ZqrtB
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    comonad-5.0.8-ECGCXO0IDm6CmzMMLQMWdW containers-0.6.5.1
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF
    profunctors-5.6.2-IwG4rHL6atH4Ka7pLrv2VH
    random-1.2.1.2-JIamRYdFYdY4e3nutT9Pr4
    semigroupoids-5.3.7-8VadR23YqgWJtKdu0uOLHe text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html:         /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldl-1.4.16-11-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 foldl
version:              1.4.16
visibility:           public
id:                   foldl-1.4.16-4yMEf2BonGAE4SZwYdiSUC
key:                  foldl-1.4.16-4yMEf2BonGAE4SZwYdiSUC
license:              BSD-3-Clause
copyright:            2013 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.

category:             Control
abi:                  e88228ebb47ea3d6209bc1f109b942a1
exposed:              True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.NonEmpty
    Control.Foldl.Text Control.Scanl

hidden-modules:
    Control.Foldl.Optics Control.Foldl.Internal
    Control.Foldl.Util.Vector Control.Foldl.Util.MVector

import-dirs:          /usr/lib/ghc-9.2.8/site-local/foldl-1.4.16
library-dirs:         /usr/lib/ghc-9.2.8/site-local/foldl-1.4.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foldl
hs-libraries:         HSfoldl-1.4.16-4yMEf2BonGAE4SZwYdiSUC
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    comonad-5.0.8-ApzGC3RbXnnLePVoN4sF11 containers-0.6.5.1
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    profunctors-5.6.2-FWe4PQU8eE3GeDqm3R4ckm
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh
    semigroupoids-5.3.7-3HMcZlsRlqoKaeVPumQFHg text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html:         /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
